.. include:: ../../../README.rst
  :start-after: inclusion-quickstart-do-not-remove
  :end-before: inclusion-quickstart-end-do-not-remove

What Next?
----------

* Learn more about creating and defining the :doc:`dashboards` and model dashboards (i.e a dashboard DetailView) and altering the :doc:`layout` of your dashboards.

* Get our :doc:`demo` project running.

* See which :doc:`components/index` are available and how to configure these to fit your needs. See also how to :doc:`components/custom` components.

* Setup :doc:`permissions` to restrict access to your dashboards to individuals or user groups.

* Change the default :doc:`templates` and styles to match your theme.